pub enum ExecMode {
Sequential,
Parallel {
threads: Option<usize>,
partitions: Option<usize>,
},
}Expand description
Execution mode for a plan.
Sequentialruns in a single thread.Parallelruns with optional thread count and partition count hints. IfthreadsisSome(n), a global rayon thread pool withnthreads is installed for this process (first one wins; later calls are no-ops). IfpartitionsisNone, the planner’s suggestion (if any) is used, otherwiseRunner::default_partitions.
Variants